BlePeripheralCapabilities class

Constructors

BlePeripheralCapabilities({required bool supportsPeripheralMode, required bool supportsManufacturerDataInAdvertisement, required bool supportsManufacturerDataInScanResponse, required bool supportsServiceDataInAdvertisement, required bool supportsServiceDataInScanResponse, required bool supportsTargetedCharacteristicUpdate, required bool supportsAdvertisingTimeout})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsAdvertisingTimeout bool
final
supportsManufacturerDataInAdvertisement bool
final
supportsManufacturerDataInScanResponse bool
final
supportsPeripheralMode bool
final
supportsServiceDataInAdvertisement bool
final
supportsServiceDataInScanResponse bool
final
supportsTargetedCharacteristicUpdate bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited