BleConnectionParametersUpdated class
Link-layer connection parameters reported by Android onConnectionUpdated.
interval and supervisionTimeout use BLE connection parameter units (multiply interval by 1.25 for ms; supervisionTimeout by 10 for ms).
- Available extensions
Constructors
Properties
- deviceId ↔ String
-
getter/setter pair
- estimatedPriority → BleConnectionPriority?
-
Available on BleConnectionParametersUpdated, provided by the BleConnectionParametersUpdatedX extension
Rough mapping from connection interval to BleConnectionPriority.no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- interval ↔ int
-
getter/setter pair
- intervalMs → double
-
Available on BleConnectionParametersUpdated, provided by the BleConnectionParametersUpdatedX extension
Connection interval in milliseconds (interval × 1.25).no setter - isSuccess → bool
-
Available on BleConnectionParametersUpdated, provided by the BleConnectionParametersUpdatedX extension
Whether status indicates a successful parameter update (GATT_SUCCESS).no setter - latency ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ int
-
getter/setter pair
- supervisionTimeout ↔ int
-
getter/setter pair
- supervisionTimeoutMs → double
-
Available on BleConnectionParametersUpdated, provided by the BleConnectionParametersUpdatedX extension
Supervision timeout in milliseconds (supervisionTimeout × 10).no setter
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → BleConnectionParametersUpdated