UniversalBlePeripheralUnsupported class
- Inheritance
-
- Object
- UniversalBlePeripheralPlatform
- UniversalBlePeripheralUnsupported
Constructors
Properties
-
advertisingStateStream
→ Stream<
BlePeripheralAdvertisingStateChanged> -
no setterinherited
-
characteristicSubscriptionStream
→ Stream<
BlePeripheralCharacteristicSubscriptionChanged> -
no setterinherited
-
connectionStateStream
→ Stream<
BlePeripheralConnectionStateChanged> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mtuChangedStream
→ Stream<
BlePeripheralMtuChanged> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAddedStream
→ Stream<
BlePeripheralServiceAdded> -
no setterinherited
Methods
-
addService(
PeripheralService service, {bool primary = true, Duration? timeout}) → Future< void> -
override
-
clearServices(
) → Future< void> -
override
-
dispose(
) → void -
Called when this platform implementation is being replaced.
inherited
-
getAdvertisingState(
) → Future< PeripheralAdvertisingState> -
override
-
getAvailabilityState(
) → Future< PeripheralReadinessState> -
override
-
getCapabilities(
) → Future< BlePeripheralCapabilities> -
override
-
getMaximumNotifyLength(
String deviceId) → Future< int?> -
override
-
getServices(
) → Future< List< String> > -
override
-
getSubscribedClients(
String characteristicId) → Future< List< String> > -
Returns GATT client device ids currently subscribed to
characteristicId.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeService(
String serviceId) → Future< void> -
override
-
setDescriptorReadRequestHandler(
OnPeripheralDescriptorReadRequest? handler) → void -
override
-
setDescriptorWriteRequestHandler(
OnPeripheralDescriptorWriteRequest? handler) → void -
override
-
setReadRequestHandler(
OnPeripheralReadRequest? handler) → void -
override
-
setWriteRequestHandler(
OnPeripheralWriteRequest? handler) → void -
override
-
startAdvertising(
{required List< String> services, String? localName, Duration? timeout, ManufacturerData? manufacturerData, PeripheralPlatformConfig? platformConfig}) → Future<void> -
override
-
stopAdvertising(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAdvertisingState(
BlePeripheralAdvertisingStateChanged event) → void -
Push advertising state update to stream listeners.
inherited
-
updateCharacteristicSubscription(
BlePeripheralCharacteristicSubscriptionChanged event) → void -
Push characteristic subscription update to stream listeners.
inherited
-
updateCharacteristicValue(
{required String characteristicId, required Uint8List value, String? deviceId}) → Future< void> -
override
-
updateConnectionState(
BlePeripheralConnectionStateChanged event) → void -
Push connection state update to stream listeners.
inherited
-
updateMtu(
BlePeripheralMtuChanged event) → void -
Push MTU update to stream listeners.
inherited
-
updateServiceAdded(
BlePeripheralServiceAdded event) → void -
Push service added update to stream listeners.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited